@@ -6,7 +6,7 @@
 
 class KGpgChangeDisableTest : public QObject {
 	Q_OBJECT
-private slots:
+private Q_SLOTS:
 	void init();
 	void testDisableKey();
 	void testEnableKey();
