@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2009 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2009-2022 Rolf Eike Beer <kde@opensource.sf-tec.de>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -37,7 +37,7 @@ public:
 	 * everything properly
 	 */
 	KGpgSendKeys(QObject *parent, const QString &keyserver, const QStringList &keys, const QString &attropt = QString(), const bool withProgress = false, const QString &proxy = QString());
-    ~KGpgSendKeys() override;
+	~KGpgSendKeys() override = default;
 
 	void setKeyIds(const QStringList &keys);
 	/**
