@@ -1,15 +1,7 @@
 /*
- * Copyright (C) 2009,2010,2012,2014,2016,2018 Rolf Eike Beer <kde@opensource.sf-tec.de>
- */
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2009, 2010, 2012, 2014, 2016, 2018 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kgpgtransactionprivate.h"
 #include "kgpgtransaction.h"
@@ -87,7 +79,7 @@ KGpgTransactionPrivate::slotReadReady()
 				return;
 
 		} else if (line.startsWith(QLatin1String("[GNUPG:] GOOD_PASSPHRASE"))) {
-			emit m_parent->statusMessage(i18n("Got Passphrase"));
+			Q_EMIT m_parent->statusMessage(i18n("Got Passphrase"));
 
 			if (m_passwordDialog != nullptr) {
 				m_passwordDialog->close();
@@ -312,8 +304,8 @@ void
 KGpgTransactionPrivate::processDone()
 {
 	m_parent->finish();
-	emit m_parent->infoProgress(100, 100);
-	emit m_parent->done(m_success);
+	Q_EMIT m_parent->infoProgress(100, 100);
+	Q_EMIT m_parent->done(m_success);
 #ifdef KGPG_DEBUG_TRANSACTIONS
 	qCDebug(KGPG_LOG_TRANSACTIONS) << this << "result:" << m_success;
 #endif /* KGPG_DEBUG_TRANSACTIONS */
@@ -324,11 +316,7 @@ bool KGpgTransactionPrivate::keyConsidered(const QString& line)
 	if (!line.startsWith(QLatin1String("[GNUPG:] KEY_CONSIDERED ")))
 		return false;
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-	const QStringList &parts = line.split(QLatin1Char(' '), QString::SkipEmptyParts);
-#else
 	const QStringList &parts = line.split(QLatin1Char(' '), Qt::SkipEmptyParts);
-#endif
 	if (parts.count() < 3)
 		m_parent->setSuccess(KGpgTransaction::TS_MSG_SEQUENCE);
 	else if (!m_expectedFingerprints.isEmpty() &&
